
function sp=fourier(sig,t,w)
% sig: senial de la que queremos calcular la serie de Fourier
% t: Vector de tiempos sobre el que esta muestreada la senial.
% w: indices de los coeficientes que se desean calcular

paso=t(2)-t(1);
npuntos=length(t);
nfreq=length(w);
im=sqrt(-1); % numero imaginario puro
for i=1:nfreq
   integ=0;
   for j=1:npuntos
      integ=integ+sig(j)*exp(-im * w(i)*t(j))*paso; % Metodo simple de aproximar la integral.
   end
   sp(i)=integ;
end


   
